@@ -87,7 +87,7 @@ public:
 		int hit = m_pLocalListView->HitTest(wxPoint(x, y), flags, 0);
 		if (hit != -1 && (flags & wxLIST_HITTEST_ONITEM)) {
 			const CLocalFileData* const data = m_pLocalListView->GetData(hit);
-			if (data && data->dir) {
+			if (data && data->is_dir()) {
 				subdir = data->name;
 			}
 		}
@@ -164,7 +164,7 @@ public:
 
 		if (hit != -1) {
 			const CLocalFileData* const data = m_pLocalListView->GetData(hit);
-			if (!data || !data->dir) {
+			if (!data || !data->is_dir()) {
 				hit = -1;
 			}
 			else {
@@ -365,7 +365,7 @@ bool CLocalListView::DisplayDir(CLocalPath const& dirname)
 
 	if (m_hasParent) {
 		CLocalFileData data;
-		data.dir = true;
+		data.flags = CLocalFileData::flag_dir;
 		data.name = _T("..");
 		data.size = -1;
 		data.attributes = {};
@@ -428,15 +428,18 @@ regular_dir:
 		fz::native_string name;
 		while (local_filesys.get_next_file(name, wasLink, t, &data.size, &data.time, &data.attributes)) {
 			data.name = fz::to_wstring(name);
-			data.dir = t == fz::local_filesys::dir;
+			data.flags = (t == fz::local_filesys::dir) ? CLocalFileData::flag_dir : 0;
+			if (wasLink) {
+				data.flags |= CLocalFileData::flag_link;
+			}
 			if (name.empty() || data.name.empty()) {
 				wxGetApp().DisplayEncodingWarning();
 				continue;
 			}
 
 			m_fileData.push_back(data);
-			if (!filter.FilenameFiltered(data.name, m_dir.GetPath(), data.dir, data.size, true, data.attributes, data.time)) {
-				if (data.dir) {
+			if (!filter.FilenameFiltered(data.name, m_dir.GetPath(), data.is_dir(), data.size, true, data.attributes, data.time)) {
+				if (data.is_dir()) {
 					++totalDirCount;
 				}
 				else {
@@ -463,7 +466,7 @@ regular_dir:
 
 	if (m_dropTarget != -1) {
 		CLocalFileData* data = GetData(m_dropTarget);
-		if (!data || !data->dir) {
+		if (!data || !data->is_dir()) {
 			SetItemState(m_dropTarget, 0, wxLIST_STATE_DROPHILITED);
 			m_dropTarget = -1;
 		}
@@ -512,7 +515,7 @@ int CLocalListView::OnGetItemImage(long item) const
 			}
 		}
 
-		icon = pThis->GetIconIndex(data->dir ? iconType::dir : iconType::file, path);
+		icon = pThis->GetIconIndex(data->is_dir() ? iconType::dir : iconType::file, path, true, data->is_link());
 	}
 	return icon;
 }
@@ -553,7 +556,7 @@ void CLocalListView::OnItemActivated(wxListEvent &event)
 		return;
 	}
 
-	if (data->dir) {
+	if (data->is_dir()) {
 		const int action = options_.get_int(OPTION_DOUBLECLICK_ACTION_DIRECTORY);
 		if (action == 3) {
 			// No action
@@ -632,7 +635,7 @@ void CLocalListView::OnMenuEnter(wxCommandEvent &)
 	}
 
 	CLocalFileData *data = GetData(item);
-	if (!data || !data->dir) {
+	if (!data || !data->is_dir()) {
 		wxBell();
 		return;
 	}
@@ -664,7 +667,7 @@ void CLocalListView::DisplayDrives()
 		CLocalFileData data;
 		data.name = drive;
 		data.label = fz::sparse_optional<std::wstring>(data.name);
-		data.dir = true;
+		data.flags = CLocalFileData::flag_dir;
 		data.size = -1;
 		data.icon = GetIconIndex(iconType::dir, std::wstring(), false);
 
@@ -725,7 +728,7 @@ void CLocalListView::DisplayShares(wxString computer)
 #ifdef __WXMSW__
 			data.label = fz::sparse_optional<std::wstring>(data.name);
 #endif
-			data.dir = true;
+			data.flags = CLocalFileData::flag_dir;
 			data.size = -1;
 
 			m_fileData.push_back(data);
@@ -855,7 +858,7 @@ void CLocalListView::OnContextMenu(wxContextMenuEvent& event)
 		if ((data && data->comparison_flags == fill) || (!index && m_hasParent)) {
 			fillCount++;
 		}
-		if (data && data->dir) {
+		if (data && data->is_dir()) {
 			selectedDir = true;
 		}
 		index = GetNextItem(index, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
@@ -934,7 +937,7 @@ void CLocalListView::OnMenuUpload(wxCommandEvent& event)
 			break;
 		}
 
-		if (data->dir) {
+		if (data->is_dir()) {
 			CLocalPath localPath = m_dir;
 			if (!localPath.ChangePath(data->name)) {
 				continue;
@@ -1216,12 +1219,12 @@ void CLocalListView::ApplyCurrentFilter()
 		if (data.comparison_flags == fill) {
 			continue;
 		}
-		if (filter.FilenameFiltered(data.name, m_dir.GetPath(), data.dir, data.size, true, data.attributes, data.time)) {
+		if (filter.FilenameFiltered(data.name, m_dir.GetPath(), data.is_dir(), data.size, true, data.attributes, data.time)) {
 			++hidden;
 			continue;
 		}
 
-		if (data.dir) {
+		if (data.is_dir()) {
 			++totalDirCount;
 		}
 		else {
@@ -1273,7 +1276,7 @@ std::vector<std::wstring> CLocalListView::RememberSelectedItems(std::wstring& fo
 			}
 			const CLocalFileData &data = m_fileData[m_indexMapping[item]];
 			if (data.comparison_flags != fill) {
-				if (data.dir) {
+				if (data.is_dir()) {
 					selectedNames.push_back(L"d" + data.name);
 				}
 				else {
@@ -1344,7 +1347,7 @@ void CLocalListView::ReselectItems(const std::vector<std::wstring>& selectedName
 				focused.clear();
 				focusedItem = -1;
 			}
-			if (data.dir && selectedName == (_T("d") + data.name)) {
+			if (data.is_dir() && selectedName == (_T("d") + data.name)) {
 				if (firstSelected == -1) {
 					firstSelected = i;
 				}
@@ -1527,10 +1530,13 @@ void CLocalListView::RefreshFile(std::wstring const& file)
 	}
 
 	data.name = file;
-	data.dir = type == fz::local_filesys::dir;
+	data.flags = (type == fz::local_filesys::dir) ? CLocalFileData::flag_dir : 0;
+	if (wasLink) {
+		data.flags |= CLocalFileData::flag_link;
+	}
 
 	CStateFilterManager const& filter = m_state.GetStateFilterManager();
-	if (filter.FilenameFiltered(data.name, m_dir.GetPath(), data.dir, data.size, true, data.attributes, data.time)) {
+	if (filter.FilenameFiltered(data.name, m_dir.GetPath(), data.is_dir(), data.size, true, data.attributes, data.time)) {
 		return;
 	}
 
@@ -1561,13 +1567,13 @@ void CLocalListView::RefreshFile(std::wstring const& file)
 						continue;
 					}
 
-					if (oldData.dir) {
+					if (oldData.is_dir()) {
 						m_pFilelistStatusBar->UnselectDirectory();
 					}
 					else {
 						m_pFilelistStatusBar->UnselectFile(oldData.size);
 					}
-					if (data.dir) {
+					if (data.is_dir()) {
 						m_pFilelistStatusBar->SelectDirectory();
 					}
 					else {
@@ -1577,13 +1583,13 @@ void CLocalListView::RefreshFile(std::wstring const& file)
 				}
 			}
 
-			if (oldData.dir) {
+			if (oldData.is_dir()) {
 				m_pFilelistStatusBar->RemoveDirectory();
 			}
 			else {
 				m_pFilelistStatusBar->RemoveFile(oldData.size);
 			}
-			if (data.dir) {
+			if (data.is_dir()) {
 				m_pFilelistStatusBar->AddDirectory();
 			}
 			else {
@@ -1608,7 +1614,7 @@ void CLocalListView::RefreshFile(std::wstring const& file)
 		return;
 	}
 
-	if (data.dir) {
+	if (data.is_dir()) {
 		m_pFilelistStatusBar->AddDirectory();
 	}
 	else {
@@ -1713,7 +1719,7 @@ void CLocalListView::StartComparison()
 
 	if (m_fileData.empty() || m_fileData.back().comparison_flags != fill) {
 		CLocalFileData data;
-		data.dir = false;
+		data.flags = 0;
 		data.icon = -1;
 		data.size = -1;
 		data.attributes = {};
@@ -1736,7 +1742,7 @@ bool CLocalListView::get_next_file(std::wstring_view & name, std::wstring &, boo
 	CLocalFileData const& data = m_fileData[index];
 
 	name = data.name;
-	dir = data.dir;
+	dir = data.is_dir();
 	size = data.size;
 	date = data.time;
 
@@ -1796,7 +1802,7 @@ wxString CLocalListView::GetItemText(int item, unsigned int column)
 		}
 
 		if (data->fileType.empty()) {
-			data->fileType = GetType(data->name, data->dir, m_dir.GetPath());
+			data->fileType = GetType(data->name, data->is_dir(), m_dir.GetPath());
 		}
 
 		return data->fileType;
@@ -1842,7 +1848,7 @@ void CLocalListView::OnMenuEdit(wxCommandEvent&)
 			continue;
 		}
 
-		if (data->dir) {
+		if (data->is_dir()) {
 			wxBell();
 			return;
 		}
@@ -1911,7 +1917,7 @@ void CLocalListView::OnMenuOpen(wxCommandEvent&)
 	}
 
 	for (auto const& data : selected_item_list) {
-		if (data.dir) {
+		if (data.is_dir()) {
 			CLocalPath path(m_dir);
 			if (!path.ChangePath(data.name)) {
 				wxBell();
@@ -1953,7 +1959,7 @@ bool CLocalListView::ItemIsDir(int index) const
 	if (index < 0 || static_cast<size_t>(index) >= m_fileData.size()) {
 		return false;
 	}
-	return m_fileData[index].dir;
+	return m_fileData[index].is_dir();
 }
 
 int64_t CLocalListView::ItemGetSize(int index) const
@@ -2007,6 +2013,15 @@ void CLocalListView::OnVolumesEnumerated(wxCommandEvent& event)
 	}
 }
 
+int CLocalListView::GetOverlayIndex(int item)
+{
+	CLocalFileData* data = GetData(item);
+	if (!data || !data->is_link()) {
+		return 0;
+	}
+	return GetLinkOverlayIndex();
+}
+
 #endif
 
 void CLocalListView::OnMenuRefresh(wxCommandEvent&)
